const express = require('express');
const router = express.Router();
const db = require('../db');
const auth = require('../middleware/auth');

// POST /api/beats/upload (Protected)
router.post('/upload', auth, (req, res) => {
  const {
    title,
    description,
    genre,
    bpm,
    key_signature,
    mood,
    has_stems = false,
    has_vocal_hook = false,
    duration_seconds,
    preview_url,
    cover_image_url,
    price_start,
    ends_at
  } = req.body;

  const artist_id = req.user.id;

  const sql = `
    INSERT INTO beats (
      title, description, genre, bpm, key_signature, mood,
      has_stems, has_vocal_hook, duration_seconds,
      preview_url, cover_image_url, price_start, artist_id, ends_at
    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
  `;

  const values = [
    title,
    description,
    genre,
    parseInt(bpm),
    key_signature,
    mood,
    Boolean(has_stems),
    Boolean(has_vocal_hook),
    parseInt(duration_seconds),
    preview_url,
    cover_image_url,
    parseFloat(price_start),
    artist_id,
    ends_at // format: "2025-04-17 18:00:00"
  ];

  db.query(sql, values, (err, result) => {
    if (err) {
      console.error('❌ Failed to upload beat:', err);
      return res.status(500).json({ error: 'Database error', details: err });
    }

    console.log('✅ Beat uploaded by user:', artist_id);
    res.json({ message: 'Beat uploaded successfully', beat_id: result.insertId });
  });
});

// GET /api/beats (Public)
router.get('/', (req, res) => {
  const { genre, mood, min_bpm, max_bpm, sort } = req.query;

  let sql = 'SELECT * FROM beats WHERE 1=1';
  const params = [];

  if (genre) {
    sql += ' AND genre = ?';
    params.push(genre);
  }

  if (mood) {
    sql += ' AND mood = ?';
    params.push(mood);
  }

  if (min_bpm) {
    sql += ' AND bpm >= ?';
    params.push(Number(min_bpm));
  }

  if (max_bpm) {
    sql += ' AND bpm <= ?';
    params.push(Number(max_bpm));
  }

  switch (sort) {
    case 'ends_first':
      sql += ' ORDER BY ends_at ASC';
      break;
    case 'ends_last':
      sql += ' ORDER BY ends_at DESC';
      break;
    case 'price_low':
      sql += ' ORDER BY price_start ASC';
      break;
    case 'price_high':
      sql += ' ORDER BY price_start DESC';
      break;
    default:
      sql += ' ORDER BY created_at DESC';
  }

  db.query(sql, params, (err, results) => {
    if (err) {
      console.error('❌ Failed to fetch beats:', err);
      return res.status(500).json({ error: 'Database error', details: err });
    }

    res.json({ beats: results });
  });
});

module.exports = router;
