const express = require('express');
const router = express.Router();
const db = require('../db');
const auth = require('../middleware/auth');

// Place a bid (protected)
router.post('/place', auth, (req, res) => {
  const { beat_id, amount } = req.body;
  const user_id = req.user.id;

  // Basic validation
  if (!beat_id || !amount) {
    return res.status(400).json({ error: 'Missing beat_id or amount' });
  }

  const sql = `
    INSERT INTO bids (beat_id, user_id, amount)
    VALUES (?, ?, ?)
  `;

  db.query(sql, [beat_id, user_id, amount], (err, result) => {
    if (err) {
      console.error('❌ Failed to place bid:', err);
      return res.status(500).json({ error: 'Database error' });
    }

    const bid = {
      id: result.insertId,
      beat_id,
      user_id,
      amount,
      created_at: new Date()
    };

    // 🔥 Broadcast new bid to all connected users
    const io = req.app.get('io');
    if (io) {
      io.emit('newBid', bid);
    }

    res.json({
      message: 'Bid placed successfully',
      bid
    });
  });
});

module.exports = router;
