const express = require('express');
const http = require('http');
const path = require('path');
const cors = require('cors');
const { Server } = require('socket.io');
require('dotenv').config();

const authRoutes = require('./routes/auth');
const beatRoutes = require('./routes/beats');
const bidRoutes = require('./routes/bid');
const db = require('./db');

const app = express();
const server = http.createServer(app);

// Middlewares
app.use(cors());
app.use(cors({
  origin: 'https://beatbid.io',
  methods: ['GET', 'POST'],
  credentials: true
}));

app.use(express.json());

// API Routes
app.use('/api', authRoutes);
app.use('/api/beats', beatRoutes);
app.use('/api/bids', bidRoutes);

// WebSocket setup
const io = new Server(server, {
  cors: {
    origin: 'https://beatbid.io',
    methods: ['GET', 'POST']
  }
});

app.set('io', io);

io.on('connection', (socket) => {
  console.log('User connected:', socket.id);
  socket.on('disconnect', () => {
    console.log('User disconnected:', socket.id);
  });
});

// ✅ Health check route
app.get('/status', (req, res) => {
  db.query('SELECT 1 + 1 AS result', (err, results) => {
    if (err) {
      res.send(`<h1>❌ Database connection failed</h1><pre>${err.message}</pre>`);
    } else {
      res.send(`<h1>✅ BeatBid Backend is Running</h1><p>MySQL says: 1 + 1 = ${results[0].result}</p>`);
    }
  });
});

// ✅ Serve React frontend (build contents inside /public)
app.use(express.static(path.join(__dirname, 'public')));

app.get('*', (req, res) => {
  res.sendFile(path.join(__dirname, 'public', 'index.html'));
});

// Start server
const PORT = process.env.PORT || 3000;
server.listen(PORT, () => {
  console.log(`🚀 Server running on port ${PORT}`);
});
